package com.displaynone.acss.components.acs.models.visit

import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.paging.PagingDataAdapter
import androidx.recyclerview.widget.DiffUtil
import androidx.recyclerview.widget.RecyclerView
import com.displaynone.acss.components.acs.models.visit.repository.dto.VisitDto
import com.displaynone.acss.components.acs.models.visit.repository.dto.VisitType
import com.displaynone.acss.databinding.ItemScannerViewBinding
import java.text.SimpleDateFormat
import java.util.Locale

class VisitAdapter : PagingDataAdapter<VisitDto, VisitAdapter.ViewHolder>(VisitDiff) {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        return ViewHolder(
            ItemScannerViewBinding.inflate(
                LayoutInflater.from(parent.context),
                parent,
                false
            )
        )
    }

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        holder.bind(
            getItem(position) ?: VisitDto(
                id = -1,
                userId = -1,
                gateId = -1,
                createdAt = "Loading...",
                visitType = VisitType.APP
            )
        )
    }

    class ViewHolder(
        private val binding: ItemScannerViewBinding
    ) : RecyclerView.ViewHolder(binding.root) {
        fun bind(item: VisitDto) {
            binding.scanTime.text = "${formatDate(item.createdAt)}"
            binding.scannerId.text = "Id турникета - " + item.gateId.toString()
            binding.passType.text = "Тип прохода - " + item.visitType.toString()
        }

        private fun formatDate(inputDate: String): String {
            val inputFormat = SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss", Locale.getDefault())
            val outputFormat = SimpleDateFormat("d MMMM yyyy 'в' HH:mm", Locale.getDefault())

            val date = inputFormat.parse(inputDate)
            if (date != null) {
                return outputFormat.format(date)


            }
            return TODO("")
        }
    }

    object VisitDiff : DiffUtil.ItemCallback<VisitDto>() {
        override fun areItemsTheSame(oldItem: VisitDto, newItem: VisitDto): Boolean {
            return oldItem.id == newItem.id
        }

        override fun areContentsTheSame(oldItem: VisitDto, newItem: VisitDto): Boolean {
            return oldItem == newItem
        }

    }

}